.. include:: ../BADGES.rst

Command Line
============

Help::

     plottoolbox –help

about
~~~~~
.. program-output:: plottoolbox about --help
   :prompt:

accumulate
~~~~~~~~~~
.. program-output:: plottoolbox accumulate --help
   :prompt:

add_trend
~~~~~~~~~
.. program-output:: plottoolbox add_trend --help
   :prompt:

aggregate
~~~~~~~~~
.. program-output:: plottoolbox aggregate --help
   :prompt:

calculate_fdc
~~~~~~~~~~~~~
.. program-output:: plottoolbox calculate_fdc --help
   :prompt:

calculate_kde
~~~~~~~~~~~~~
.. program-output:: plottoolbox calculate_kde --help
   :prompt:

clip
~~~~
.. program-output:: plottoolbox clip --help
   :prompt:

convert
~~~~~~~
.. program-output:: plottoolbox convert --help
   :prompt:

convert_index
~~~~~~~~~~~~~~~~~~~~~~~
.. program-output:: plottoolbox convert_index --help
   :prompt:

convert_index_to_julian
~~~~~~~~~~~~~~~~~~~~~~~
.. program-output:: plottoolbox convert_index_to_julian --help
   :prompt:

converttz
~~~~~~~~~
.. program-output:: plottoolbox converttz --help
   :prompt:

correlation
~~~~~~~~~~~
.. program-output:: plottoolbox correlation --help
   :prompt:

createts
~~~~~~~~
.. program-output:: plottoolbox createts --help
   :prompt:

date_offset
~~~~~~~~~~~
.. program-output:: plottoolbox date_offset --help
   :prompt:

date_slice
~~~~~~~~~~
.. program-output:: plottoolbox date_slice --help
   :prompt:

describe
~~~~~~~~
.. program-output:: plottoolbox describe --help
   :prompt:

dtw
~~~
.. program-output:: plottoolbox dtw --help
   :prompt:

equation
~~~~~~~~
.. program-output:: plottoolbox equation --help
   :prompt:

ewm_window
~~~~~~~~~~
.. program-output:: plottoolbox ewm_window --help
   :prompt:

expanding_window
~~~~~~~~~~~~~~~~
.. program-output:: plottoolbox expanding_window --help
   :prompt:

fill
~~~~
.. program-output:: plottoolbox fill --help
   :prompt:

filter
~~~~~~
.. program-output:: plottoolbox filter --help
   :prompt:

gof
~~~
.. program-output:: plottoolbox gof --help
   :prompt:

lag
~~~
.. program-output:: plottoolbox lag --help
   :prompt:

normalization
~~~~~~~~~~~~~
.. program-output:: plottoolbox normalization --help
   :prompt:

pca
~~~
.. program-output:: plottoolbox pca --help
   :prompt:

pct_change
~~~~~~~~~~
.. program-output:: plottoolbox pct_change --help
   :prompt:

peak_detection
~~~~~~~~~~~~~~
.. program-output:: plottoolbox peak_detection --help
   :prompt:

pick
~~~~
.. program-output:: plottoolbox pick --help
   :prompt:

plot
~~~~
.. program-output:: plottoolbox plot --help
   :prompt:

rank
~~~~
.. program-output:: plottoolbox rank --help
   :prompt:

read
~~~~
.. program-output:: plottoolbox read --help
   :prompt:

remove_trend
~~~~~~~~~~~~
.. program-output:: plottoolbox remove_trend --help
   :prompt:

replace
~~~~~~~
.. program-output:: plottoolbox replace --help
   :prompt:

rolling_window
~~~~~~~~~~~~~~
.. program-output:: plottoolbox rolling_window --help
   :prompt:

stack
~~~~~
.. program-output:: plottoolbox stack --help
   :prompt:

stdtozrxp
~~~~~~~~~
.. program-output:: plottoolbox stdtozrxp --help
   :prompt:

tstopickle
~~~~~~~~~~
.. program-output:: plottoolbox tstopickle --help
   :prompt:

unstack
~~~~~~~
.. program-output:: plottoolbox unstack --help
   :prompt:
